<?php

/**
 * dBlog functions and definitions.
 *
 * @package dBlog
 */
/**
 * The current version of the theme.
 */
define( 'DBLOG_VERSION', '1.0' );

if (!function_exists( 'dblog_setup' )) :

	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function dblog_setup() {
		//Make theme available for translation.
		load_theme_textdomain( 'dblog' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		//Let WordPress manage the document title.
		add_theme_support( 'title-tag' );

		//Enable support for Post Thumbnails on posts and pages .
		add_theme_support( 'post-thumbnails' );

		// Add necessary image sizes.
		add_image_size( 'dblog-thumbnail', 1200, 800, true );

		// Set the default content width.
		$GLOBALS['content_width'] = apply_filters( 'dblog_content_width', 1200 );

		// Register menu locations.
		register_nav_menus( array(
			'top' => __( 'Top Menu', 'dblog' ),
			'bottom' => __( 'Bottom Menu', 'dblog' )
		) );

		// Enable HTML5 markup for the listed features.
		add_theme_support( 'html5', array(
			'comment-list',
			'comment-form',
			'search-form',
			'gallery',
			'caption'
		) );

		// Add theme support for Custom Logo.
		add_theme_support( 'custom-logo', array(
			'width' => 200,
			'height' => 200,
			'flex-width' => true,
			'flex-height' => false,
		) );

		// Add support for Jetpack responsive videos.
		add_theme_support( 'jetpack-responsive-videos' );

		// Add support for Pageviews plugin.
		add_theme_support( 'pageviews' );
	}

endif;
add_action( 'after_setup_theme', 'dblog_setup' );

if (!function_exists( 'dblog_fonts_url' )) :

	/**
	 * Register custom fonts.
	 */
	function dblog_fonts_url() {
		$fonts_url = '';

		/*
		 * Translators: If there are characters in your language that are not
		 * supported by PT Sans, translate this to 'off'. Do not translate
		 * into your own language.
		 */
		$pt_sans = _x( 'on', 'PT Sans font: on or off', 'dblog' );

		if ('off' !== $pt_sans) {
			$font_families = array();

			$font_families[] = 'PT Sans:400,400i,700,700i';

			$query_args = array(
				'family' => urlencode( implode( '|', $font_families ) ),
				'subset' => urlencode( 'latin,latin-ext' ),
			);

			$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
		}

		return esc_url_raw( $fonts_url );
	}

endif;

/**
 * Enqueue scripts and styles.
 */
function dblog_scripts() {
	$tpl = get_template_directory_uri();

	wp_enqueue_style( 'reset', $tpl . '/assets/css/reset.css' );
	wp_enqueue_style( 'dblog-fonts', dblog_fonts_url() );
	wp_enqueue_style( 'font-awesome', $tpl . '/assets/css/fontawesome/css/all.css', array(), '5.1.0' );
	wp_enqueue_style( 'magnific-popup', $tpl . '/assets/css/magnific-popup.css', array(), '1.1.0' );
	wp_enqueue_style( 'dblog-style', get_stylesheet_uri(), array(), DBLOG_VERSION );

	wp_enqueue_script( 'dblog-skip-link-focus-fix', $tpl . '/assets/js/skip-link-focus-fix.js', array(), DBLOG_VERSION, true );
	wp_enqueue_script( 'dblog-responsive-embeds', $tpl . '/assets/js/responsive-embeds.js', array(), DBLOG_VERSION, true );
	wp_enqueue_script( 'magnific-popup', $tpl . '/assets/js/jquery.magnific-popup.min.js', array('jquery'), '1.1.0' );
	wp_enqueue_script( 'dblog-scripts', $tpl . '/assets/js/dblog.js', array('jquery'), DBLOG_VERSION, true );

	if (is_singular() && comments_open() && get_option( 'thread_comments' )) {
		wp_enqueue_script( 'comment-reply' );
	}
}

add_action( 'wp_enqueue_scripts', 'dblog_scripts' );

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer settings.
 */
require get_template_directory() . '/inc/customizer.php';
