<?php

/**
 * dBlog Theme Customizer
 *
 * @package dBlog
 */

/**
 * Add theme-specific Customizer settings and controls.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function dblog_customize_register( $wp_customize ) {
	// Add selective refresh for general settings
	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	$wp_customize->selective_refresh->add_partial( 'blogname', array(
		'selector' => '.site-name a',
		'render_callback' => function() {
			return get_bloginfo( 'name' );
		}
	) );

	$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
		'selector' => '.site-desc',
		'render_callback' => function() {
			return get_bloginfo( 'description' );
		}
	) );

	// Gravatar as Site logo.
	$wp_customize->add_setting( 'use_gravatar_as_logo', array(
		'default' => 0,
		'sanitize_callback' => 'dblog_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'use_gravatar_as_logo', array(
		'type' => 'checkbox',
		'label' => __( 'Use Gravatar as Logo', 'dblog' ),
		'section' => 'title_tagline',
		// Translators: placeholder shows the site admin email.
		'description' => sprintf( __( 'Use your gravatar associated with <strong>%s</strong> as a site logo image. This will override the logo set manually.', 'dblog' ), esc_html( get_bloginfo( 'admin_email' ) ) ) . '<br />' . sprintf( '<a href="%s" target="_blank">%s</a>', esc_url( __( 'https://en.gravatar.com/support/what-is-gravatar/', 'dblog' ) ), __( 'What is Gravatar?', 'dblog' ) ),
		'priority' => 9,
	) );

	//Social Links
	$wp_customize->add_section( 'dblog_socials', array(
		'title' => __( 'Social Links', 'dblog' )
	) );

	for ($i = 1; $i <= 10; $i ++) {
		$wp_customize->add_setting( 'social_link' . $i, array(
			'default' => '',
			'sanitize_callback' => 'esc_url_raw',
			'transport' => 'postMessage'
		) );

		$wp_customize->add_control( 'social_link' . $i, array(
			'label' => __( 'Social Link', 'dblog' ) . ' ' . $i,
			'section' => 'dblog_socials'
		) );

		$wp_customize->selective_refresh->add_partial( 'social_link' . $i, array(
			'selector' => '.social-link-' . $i,
			'container_inclusive' => true,
			'render_callback' => function() use ($i) {
				$url = get_theme_mod( 'social_link' . $i );
				return '<a href="' . esc_url( $url ) . '">' . $i . '</a>';
			}
		) );
	}
}

add_action( 'customize_register', 'dblog_customize_register' );

/**
 * Sanitizes checkbox.
 *
 * @param string|int $input Potentially harmful data.
 */
function dblog_sanitize_checkbox( $input ) {
	return 1 == $input ? 1 : 0;
}
