<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package dBlog
 */
if (!function_exists( 'dblog_socials' )) :

	function dblog_socials() {
		?>
		<div class="socials">
			<?php
			for ($i = 1; $i <= 10; $i ++) :
				$url = get_theme_mod( 'social_link' . $i );
				if ($url) :
					?>
					<a href="<?php echo esc_url( $url ); ?>" class="fab" target="_blank"></a>
					<?php
				endif;
			endfor;
			?>
		</div><!-- .socials -->
		<?php
	}

endif;

if (!function_exists( 'dblog_post_thumbnail_archive' )) :

	/**
	 * Displays post thumbnail.
	 */
	function dblog_post_thumbnail_archive() {
		if (post_password_required() || is_attachment() || !has_post_thumbnail()) {
			return;
		}
		?>
		<a href="<?php the_permalink(); ?>" class="archive-thumbnail post-thumbnail"><?php the_post_thumbnail( 'dblog-thumbnail' ); ?></a>
		<?php
	}

endif;

if (!function_exists( 'dblog_post_header_archive' )) :

	/**
	 * Displays post header.
	 */
	function dblog_post_header_archive() {
		$title = trim( get_the_title() );
		if (!empty( $title )) :
			?>
			<header class="post-header item-header">

				<?php the_title( sprintf( '<h2 class="post-title item-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' ); ?>

			</header><!-- .post-header -->
			<?php
		endif;
	}

endif;

if (!function_exists( 'dblog_entry_pageviews' )) :

	/**
	 * Displays post meta information
	 */
	function dblog_entry_pageviews() {
		if (!has_action( 'pageviews' )) {
			return;
		}

		printf( '<span class="entry-meta-item pageviews">%1$s %2$s</span>', // WPCS: XSS OK.
				'<i class="far fa-eye" aria-hidden="true"></i>', Pageviews::get_placeholder( get_the_ID() )
		);
	}

endif;

if (!function_exists( 'dblog_post_meta' )) :

	/**
	 * Displays post meta information
	 */
	function dblog_post_meta() {
		?><div class="post-meta">
			<div class="date">
				<?php
				$title = trim( get_the_title() );
				if (!empty( $title )) :
					echo get_the_date();
				else :
					?>
					<a href="<?php the_permalink() ?>"><?php echo get_the_date(); ?></a>
				<?php endif; ?>
			</div>
			<div class="categories"><?php the_category( ' ' ); ?></div>
			<?php the_tags( '<div class="tags">' . __( 'Tags: ', 'dblog' ), ', ', '</div>' ); ?>
			<?php dblog_entry_pageviews(); ?>
		</div><!-- .post-meta --><?php
	}

endif;

if (!function_exists( 'dblog_first_post_link' )) :

	/**
	 * Displays a link to the Dashboard new post page.
	 */
	function dblog_first_post_link() {
		// Only allow links in the message.
		$args = array(
			'a' => array(
				'href' => array(),
			),
		);

		// Sanitize and print the message.
		printf(
				wp_kses(
						/* Translators: 1: link to WP admin new post page. */
						__( 'Ready to publish your first post? <a href="%1$s">Get started here</a>.', 'dblog' ), $args
				), esc_url( admin_url( 'post-new.php' ) )
		);
	}

endif;

if (!function_exists( 'dblog_footer_copy' )) :

	function dblog_footer_copy() {
		?><div class="footer-copy">&copy; <?php echo date_i18n( 'Y' ); ?> <?php bloginfo( 'name' ); ?></div><?php
	}

endif;

if (!function_exists( 'dblog_theme_copy' )) :

	function dblog_theme_copy() {
		?><div class="theme-copy">dBlog theme by <a href="http://denisco.pro/?from=dblog" target="_blank">Denis Yanchevskiy</a></div><?php
	}
	
endif;